Crate tsuzuri

Crate tsuzuri 

Re-exports

pub use command::repository::AggregateCommiter;
pub use command::repository::AggregateLoader;
pub use command::repository::EventSourced;
pub use command::repository::Repository;
pub use command::handler;
pub use command::repository;
pub use command::Command;

Modules

aggregate_id
command
domain_event
error
event
event_store
helper
integration
integration_event
inverted_index_store
mem_store
message
persist
projection
sequence_number
serde
snapshot
test
Test framework for tsuzuri aggregates
version

Structs

EventId
VersionedAggregate
A wrapper around an aggregate root that tracks version and sequence number for event sourcing and optimistic concurrency control.

Traits

AggregateRoot
Trait that aggregates must implement to provide their ID prefix and handle commands and domain events.

Type Aliases

EventIdType