Re-exports
pub use command::repository::AggregateCommiter;pub use command::repository::AggregateLoader;pub use command::repository::EventSourced;pub use command::repository::Repository;pub use command::handler;pub use command::repository;pub use command::Command;
Modules
- aggregate_
id - command
- domain_
event - error
- event
- event_
store - helper
- integration
- integration_
event - inverted_
index_ store - mem_
store - message
- persist
- projection
- sequence_
number - serde
- snapshot
- test
- Test framework for tsuzuri aggregates
- version
Structs
- EventId
- Versioned
Aggregate - A wrapper around an aggregate root that tracks version and sequence number for event sourcing and optimistic concurrency control.
Traits
- Aggregate
Root - Trait that aggregates must implement to provide their ID prefix and handle commands and domain events.